@@ -34,7 +34,7 @@ def test_readme_example_seq():
     # Run it #
     c()
     # Check that the results are good #
-    assert c.queries[0].taxonomy[0] == "Synechococcales"
+    assert c.queries[0].taxonomy[0] == "Nodosilinea PCC-7104"
     # Return #
     return c
 
